@@ -15,16 +15,16 @@ import org.gcube.common.authorization.library.provider.SecurityTokenProvider;
 import org.gcube.common.authorization.library.provider.UserInfo;
 import org.gcube.common.portal.PortalContext;
 import org.gcube.common.scope.api.ScopeProvider;
-import org.gcube.datacatalogue.ckanutillibrary.server.ApplicationProfileScopePerUrlReader;
+import org.gcube.datacatalogue.utillibrary.server.ApplicationProfileScopePerUrlReader;
+import org.gcube.portlets.widgets.ckandatapublisherwidget.server.CKANPublisherServicesImpl;
 import org.gcube.vomanagement.usermanagement.GroupManager;
 import org.gcube.vomanagement.usermanagement.exception.GroupRetrievalFault;
 import org.gcube.vomanagement.usermanagement.exception.UserManagementSystemException;
 import org.gcube.vomanagement.usermanagement.impl.LiferayGroupManager;
 import org.gcube.vomanagement.usermanagement.model.GCubeGroup;
 import org.gcube.vomanagement.usermanagement.model.GCubeUser;
-
-import com.liferay.portal.kernel.log.Log;
-import com.liferay.portal.kernel.log.LogFactoryUtil;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * Util class with static methods.
@@ -35,7 +35,7 @@ public class GenericUtils {
 
 	// Logger
 	//private static final org.slf4j.Logger logger = LoggerFactory.getLogger(Utils.class);
-	private static final Log logger = LogFactoryUtil.getLog(GenericUtils.class);
+	private static final Logger logger = LoggerFactory.getLogger(GenericUtils.class);
 	public static final String GCUBE_REQUEST_URL = "gcube-request-url";
 
 	/**
@@ -52,13 +52,18 @@ public class GenericUtils {
 		GroupManager gm = new LiferayGroupManager();
 		List<GCubeGroup> groups = gm.listGroups();
 		for (GCubeGroup gCubeGroup : groups) {
-			if(gCubeGroup.getGroupName().equalsIgnoreCase(organizationName))
-				return gm.getInfrastructureScope(gCubeGroup.getGroupId());
+			if(gCubeGroup.getGroupName().equalsIgnoreCase(organizationName)) {
+				String theScope = gm.getInfrastructureScope(gCubeGroup.getGroupId());
+				logger.info("For organizationName: " + organizationName+" by using "+LiferayGroupManager.class.getSimpleName()+ " got the scope: "+theScope +", returning it");
+				return theScope;
+			}
 		}
-
+		
+		logger.info("No scope detected for organizationName: " + organizationName +" by using "+LiferayGroupManager.class.getSimpleName());
 		return null;
 	}
 
+
 	/**
 	 * First check to retrieve the token, else create it.
 	 *
@@ -159,9 +164,16 @@ public class GenericUtils {
 	 * @return a GcubeUser object
 	 */
 	public static GCubeUser getCurrentUser(HttpServletRequest request){
-
-		if(request == null)
-			throw new IllegalArgumentException("HttpServletRequest is null!");
+		
+		if(request == null) {
+			if (!CKANPublisherServicesImpl.isWithinPortal()) {
+				String testUserName = "testuser";
+				logger.debug("Test mode is enabled, returning test user: " + testUserName);
+				return new GCubeUser(0, testUserName, testUserName, testUserName, testUserName, testUserName, testUserName, 0, testUserName, false, testUserName, null);
+				
+			}else
+				throw new IllegalArgumentException("HttpServletRequest is null!");
+		}
 
 		PortalContext pContext = PortalContext.getConfiguration();
 		GCubeUser user = pContext.getCurrentUser(request);
@@ -178,9 +190,15 @@ public class GenericUtils {
 	 */
 	public static String getCurrentContext(HttpServletRequest request, boolean setInThread){
 
-		if(request == null)
-			throw new IllegalArgumentException("HttpServletRequest is null!");
-
+		if(request == null){
+			if (!CKANPublisherServicesImpl.isWithinPortal()) {
+				String scope = ScopeProvider.instance.get();
+				logger.debug("Test mode is enabled, returning test scope: " + scope);
+				return scope;
+				
+			}else
+				throw new IllegalArgumentException("HttpServletRequest is null!");
+		}
 		PortalContext pContext = PortalContext.getConfiguration();
 		String context = pContext.getCurrentScope(request);
 		logger.debug("Returning context " + context);
@@ -190,7 +208,7 @@ public class GenericUtils {
 
 		return context;
 	}
-
+	
 	/**
 	 * Retrieve the current token by using the portal manager.
 	 *
